﻿
using System;
using System.Linq;
using Wisej.Web;

namespace Wisej.StockQuotesSample
{
	public partial class Page1 : Page
	{
		public Page1()
		{
			InitializeComponent();

			this.Disposed += Page1_Disposed;
		}

		private void listBox1_SelectedIndexChanged(object sender, EventArgs e)
		{
			this.button1.Enabled = this.listBox1.SelectedIndex > -1;
		}

		private void Page1_Load(object sender, EventArgs e)
		{
			this.listBox1.Items.AddRange(StockList.List);

			Application.BeginRequest += Application_BeginRequest;
			QuoteServer.QuotesUpdated += QuoteServer_QuotesUpdated;
		}

		private void Application_BeginRequest(object sender, EventArgs e)
		{
			// check if we are in websocket mode. need
			// to check here since on first load Application.IsWebSocket is always false
			// because the first request is always http.

			// on Program.Main we can only check client's capabilities using
			// Application.Browser.Features.webSocket == true.

			if (!Application.IsWebSocket && this._updateTimer == null)
			{
				// fallback to the timer.
				this._updateTimer = new Timer(this.components);
				this._updateTimer.Interval = 2000;
				this._updateTimer.Start();
			}
		}
		private Timer _updateTimer = null;

		private void Page1_Disposed(object sender, EventArgs e)
		{
			Application.BeginRequest -= Application_BeginRequest;
			QuoteServer.QuotesUpdated -= QuoteServer_QuotesUpdated;
		}

		private void QuoteServer_QuotesUpdated(object sender, QuotesUpdatedEventargs e)
		{
			Application.Update(this, () =>
			{
				foreach (StockQuote item in this.panel1.Controls)
				{
					var index = Array.IndexOf(e.Stocks, item.Stock);
					if (index > -1)
					{
						item.Quote = e.Quotes[index];

						// animate when the value changes.
						this.animation1.Run(item);
					}
				}

				this.label4.Text = DateTime.Now.ToString();
			});
		}

		private void button1_Click(object sender, EventArgs e)
		{
			var stock = (string)this.listBox1.SelectedItem;
			this.listBox1.Items.Remove(stock);

			var item = new StockQuote()
			{
				Quote = 0,
				Stock = stock,
				Dock = DockStyle.Top
			};
			this.panel1.Controls.Add(item);

			item.Remove += Item_Remove;
			this.animation1.GetAnimation(item).Name = "blink";
		}

		private void Item_Remove(object sender, EventArgs e)
		{
			var item = (StockQuote)sender;
			this.panel1.Controls.Remove(item);
			this.listBox1.Items.Add(item.Stock);
			item.Dispose();
		}
	}
}
